diff --git a/Translations/Language.ar.xml b/Translations/Language.ar.xml
index 26937c52..f3b70160 100644
--- a/Translations/Language.ar.xml
+++ b/Translations/Language.ar.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.be.xml b/Translations/Language.be.xml
index 33473d68..f613f6df 100644
--- a/Translations/Language.be.xml
+++ b/Translations/Language.be.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.bg.xml b/Translations/Language.bg.xml
index 9a3a7e17..f7100047 100644
--- a/Translations/Language.bg.xml
+++ b/Translations/Language.bg.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.ca.xml b/Translations/Language.ca.xml
index fbc52d9d..7de530db 100644
--- a/Translations/Language.ca.xml
+++ b/Translations/Language.ca.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.co.xml b/Translations/Language.co.xml
index b9a578c2..5056c292 100644
--- a/Translations/Language.co.xml
+++ b/Translations/Language.co.xml
@@ -1685,7 +1685,7 @@ Information about Corsican localization:
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.cs.xml b/Translations/Language.cs.xml
index d5179600..3df82da6 100644
--- a/Translations/Language.cs.xml
+++ b/Translations/Language.cs.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.da.xml b/Translations/Language.da.xml
index 5f27fa80..7e2fbe70 100644
--- a/Translations/Language.da.xml
+++ b/Translations/Language.da.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.de.xml b/Translations/Language.de.xml
index 38329b84..98371258 100644
--- a/Translations/Language.de.xml
+++ b/Translations/Language.de.xml
@@ -1668,7 +1668,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.el.xml b/Translations/Language.el.xml
index eac2ef20..eb7298b3 100644
--- a/Translations/Language.el.xml
+++ b/Translations/Language.el.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.es.xml b/Translations/Language.es.xml
index a502b33f..953334d1 100644
--- a/Translations/Language.es.xml
+++ b/Translations/Language.es.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.et.xml b/Translations/Language.et.xml
index e2988c82..aa5e3ca4 100644
--- a/Translations/Language.et.xml
+++ b/Translations/Language.et.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.eu.xml b/Translations/Language.eu.xml
index e204fe1c..a7e4af1a 100644
--- a/Translations/Language.eu.xml
+++ b/Translations/Language.eu.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.fa.xml b/Translations/Language.fa.xml
index 99cb0d97..549948d2 100644
--- a/Translations/Language.fa.xml
+++ b/Translations/Language.fa.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.fi.xml b/Translations/Language.fi.xml
index eb3f9a06..4b98a833 100644
--- a/Translations/Language.fi.xml
+++ b/Translations/Language.fi.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.fr.xml b/Translations/Language.fr.xml
index fa59bee6..c70504da 100644
--- a/Translations/Language.fr.xml
+++ b/Translations/Language.fr.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.he.xml b/Translations/Language.he.xml
index daa4e530..e1c038ea 100644
--- a/Translations/Language.he.xml
+++ b/Translations/Language.he.xml
@@ -1666,7 +1666,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.hu.xml b/Translations/Language.hu.xml
index 10d0b09a..e0870d67 100644
--- a/Translations/Language.hu.xml
+++ b/Translations/Language.hu.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.id.xml b/Translations/Language.id.xml
index 45cba292..51480291 100644
--- a/Translations/Language.id.xml
+++ b/Translations/Language.id.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.it.xml b/Translations/Language.it.xml
index 730cc66d..9f7f83c0 100644
--- a/Translations/Language.it.xml
+++ b/Translations/Language.it.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.ja.xml b/Translations/Language.ja.xml
index 7eea59c5..4437d86d 100644
--- a/Translations/Language.ja.xml
+++ b/Translations/Language.ja.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.ka.xml b/Translations/Language.ka.xml
index 770931a9..fb8a2078 100644
--- a/Translations/Language.ka.xml
+++ b/Translations/Language.ka.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.ko.xml b/Translations/Language.ko.xml
index de452c3a..ad87cbe3 100644
--- a/Translations/Language.ko.xml
+++ b/Translations/Language.ko.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.lv.xml b/Translations/Language.lv.xml
index 1009e078..5340280f 100644
--- a/Translations/Language.lv.xml
+++ b/Translations/Language.lv.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.my.xml b/Translations/Language.my.xml
index 162da9b4..e7cad2b2 100644
--- a/Translations/Language.my.xml
+++ b/Translations/Language.my.xml
@@ -1667,7 +1667,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.nb.xml b/Translations/Language.nb.xml
index a27ae7b2..813b2b2c 100644
--- a/Translations/Language.nb.xml
+++ b/Translations/Language.nb.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.nl.xml b/Translations/Language.nl.xml
index 2925fa61..a836a3c8 100644
--- a/Translations/Language.nl.xml
+++ b/Translations/Language.nl.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.nn.xml b/Translations/Language.nn.xml
index 34fa9805..d9370434 100644
--- a/Translations/Language.nn.xml
+++ b/Translations/Language.nn.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.pl.xml b/Translations/Language.pl.xml
index 9b84182b..e92b07e5 100644
--- a/Translations/Language.pl.xml
+++ b/Translations/Language.pl.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.pt-br.xml b/Translations/Language.pt-br.xml
index 1ee6d29f..5366f65d 100644
--- a/Translations/Language.pt-br.xml
+++ b/Translations/Language.pt-br.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.ro.xml b/Translations/Language.ro.xml
index 94f6d34b..c3bda878 100644
--- a/Translations/Language.ro.xml
+++ b/Translations/Language.ro.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.ru.xml b/Translations/Language.ru.xml
index ea6d754d..86d3ff14 100644
--- a/Translations/Language.ru.xml
+++ b/Translations/Language.ru.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.sk.xml b/Translations/Language.sk.xml
index 27f14087..96cf188d 100644
--- a/Translations/Language.sk.xml
+++ b/Translations/Language.sk.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.sl.xml b/Translations/Language.sl.xml
index 4e395bb9..70fa928a 100644
--- a/Translations/Language.sl.xml
+++ b/Translations/Language.sl.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.sv.xml b/Translations/Language.sv.xml
index a88fa599..c63e2349 100644
--- a/Translations/Language.sv.xml
+++ b/Translations/Language.sv.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.th.xml b/Translations/Language.th.xml
index fb6c7adb..48f0a620 100644
--- a/Translations/Language.th.xml
+++ b/Translations/Language.th.xml
@@ -1666,7 +1666,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.tr.xml b/Translations/Language.tr.xml
index dc3f7f1b..70c79100 100644
--- a/Translations/Language.tr.xml
+++ b/Translations/Language.tr.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.uk.xml b/Translations/Language.uk.xml
index d8bbcc40..0944d12f 100644
--- a/Translations/Language.uk.xml
+++ b/Translations/Language.uk.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.uz.xml b/Translations/Language.uz.xml
index 9b71a939..b7ca2334 100644
--- a/Translations/Language.uz.xml
+++ b/Translations/Language.uz.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.vi.xml b/Translations/Language.vi.xml
index 82c93657..7b564b6f 100644
--- a/Translations/Language.vi.xml
+++ b/Translations/Language.vi.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.zh-cn.xml b/Translations/Language.zh-cn.xml
index 68aae450..aee15ba2 100644
--- a/Translations/Language.zh-cn.xml
+++ b/Translations/Language.zh-cn.xml
@@ -1666,7 +1666,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.zh-hk.xml b/Translations/Language.zh-hk.xml
index 6a9c3c05..fd969015 100644
--- a/Translations/Language.zh-hk.xml
+++ b/Translations/Language.zh-hk.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/Translations/Language.zh-tw.xml b/Translations/Language.zh-tw.xml
index 7471a780..723e5c0d 100644
--- a/Translations/Language.zh-tw.xml
+++ b/Translations/Language.zh-tw.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/src/Common/Dlgcode.h b/src/Common/Dlgcode.h
index d7b2693c..e249c5d1 100644
--- a/src/Common/Dlgcode.h
+++ b/src/Common/Dlgcode.h
@@ -362,6 +362,7 @@ BOOL WriteMemoryProtectionConfig (BOOL bEnable);
BOOL ReadScreenProtectionConfig();
BOOL WriteScreenProtectionConfig(BOOL bEnable);
BOOL LoadSysEncSettings ();
+BOOL ClearSystemEncryptionStatus (HWND hwndDlg);
int LoadNonSysInPlaceEncSettings (WipeAlgorithmId *wipeAlgorithm);
void RemoveNonSysInPlaceEncNotifications (void);
void SavePostInstallTasksSettings (int command);
diff --git a/src/Common/Language.xml b/src/Common/Language.xml
index 2ec36d0b..0e7271b7 100644
--- a/src/Common/Language.xml
+++ b/src/Common/Language.xml
@@ -1665,7 +1665,7 @@
The EFI boot loader file could not be read completely:
The EFI boot loader file is unexpectedly large and was not inspected:
The system partition/drive is already decrypted and the EFI boot loader files were restored, but VeraCrypt could not remove one or more VeraCrypt firmware boot entries. The VeraCrypt EFI files were left in place so any remaining firmware entry still points to an existing loader. Retry as Administrator or remove the VeraCrypt boot entry from firmware setup after confirming Windows Boot Manager starts normally.
- The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. If decryption has just completed, reboot Windows and try again.
+ The EFI boot loader cannot be repaired while system encryption or decryption is active or incomplete. Complete or resume the pending system encryption/decryption process before retrying.
This repair action is available only on systems booting in UEFI mode from a GPT system partition.
The EFI boot loader has been repaired successfully.
diff --git a/src/Mount/Mount.c b/src/Mount/Mount.c
index a9d2d054..964314b5 100644
--- a/src/Mount/Mount.c
+++ b/src/Mount/Mount.c
@@ -1312,20 +1312,10 @@ void SaveSettings (HWND hwndDlg)
NormalCursor ();
}
-// Returns TRUE if system encryption or decryption had been or is in progress and has not been completed
-static BOOL SysEncryptionOrDecryptionRequired (void)
+static BOOL SysEncryptionOrDecryptionRequiredByCurrentStatus (void)
{
/* If you update this function, revise SysEncryptionOrDecryptionRequired() in Tcformat.c as well. */
- try
- {
- BootEncStatus = BootEncObj->GetStatus();
- }
- catch (Exception &e)
- {
- e.Show (MainDlg);
- }
-
return (SystemEncryptionStatus == SYSENC_STATUS_ENCRYPTING
|| SystemEncryptionStatus == SYSENC_STATUS_DECRYPTING
||
@@ -1340,6 +1330,21 @@ static BOOL SysEncryptionOrDecryptionRequired (void)
);
}
+// Returns TRUE if system encryption or decryption had been or is in progress and has not been completed
+static BOOL SysEncryptionOrDecryptionRequired (void)
+{
+ try
+ {
+ BootEncStatus = BootEncObj->GetStatus();
+ }
+ catch (Exception &e)
+ {
+ e.Show (MainDlg);
+ }
+
+ return SysEncryptionOrDecryptionRequiredByCurrentStatus ();
+}
+
// Returns TRUE if system encryption master key is vulnerable
static BOOL SysEncryptionMasterKeyVulnerable (void)
{
@@ -6482,11 +6487,17 @@ static void RepairEfiBootLoader (HWND hwndDlg)
return;
}
+ BOOL bSysEncRequired = SysEncryptionOrDecryptionRequired ();
+ BOOL bFinalizeDecryption = (SystemEncryptionStatus == SYSENC_STATUS_DECRYPTING
+ && !BootEncStatus.SetupInProgress
+ && !BootEncStatus.DriveEncrypted
+ && !BootEncStatus.DriveMounted);
+
if (IsHiddenOSRunning()
|| BootEncStatus.SetupInProgress
|| BootEncStatus.DriveEncrypted
|| BootEncStatus.DriveMounted
- || SysEncryptionOrDecryptionRequired ())
+ || (bSysEncRequired && !bFinalizeDecryption))
{
Warning ("EFI_BOOT_LOADER_REPAIR_BLOCKED", hwndDlg);
return;
@@ -6501,10 +6512,50 @@ static void RepairEfiBootLoader (HWND hwndDlg)
return;
}
+ LoadSysEncSettings ();
+ try
+ {
+ BootEncStatus = BootEncObj->GetStatus();
+ config = BootEncObj->GetSystemDriveConfiguration ();
+ }
+ catch (Exception &e)
+ {
+ CloseSysEncMutex ();
+ e.Show (hwndDlg);
+ return;
+ }
+
+ if (!config.SystemPartition.IsGPT)
+ {
+ CloseSysEncMutex ();
+ Warning ("EFI_BOOT_LOADER_REPAIR_NOT_APPLICABLE", hwndDlg);
+ return;
+ }
+
+ bSysEncRequired = SysEncryptionOrDecryptionRequiredByCurrentStatus ();
+ bFinalizeDecryption = (SystemEncryptionStatus == SYSENC_STATUS_DECRYPTING
+ && !BootEncStatus.SetupInProgress
+ && !BootEncStatus.DriveEncrypted
+ && !BootEncStatus.DriveMounted);
+
+ if (IsHiddenOSRunning()
+ || BootEncStatus.SetupInProgress
+ || BootEncStatus.DriveEncrypted
+ || BootEncStatus.DriveMounted
+ || (bSysEncRequired && !bFinalizeDecryption))
+ {
+ CloseSysEncMutex ();
+ Warning ("EFI_BOOT_LOADER_REPAIR_BLOCKED", hwndDlg);
+ return;
+ }
+
WaitCursor ();
try
{
- BootEncObj->RestoreSystemLoader ();
+ if (bFinalizeDecryption)
+ BootEncObj->Deinstall (true);
+ else
+ BootEncObj->RestoreSystemLoader ();
}
catch (Exception &e)
{
@@ -6514,7 +6565,19 @@ static void RepairEfiBootLoader (HWND hwndDlg)
return;
}
- NormalCursor ();
+ if (bFinalizeDecryption)
+ {
+ NormalCursor ();
+ if (!ClearSystemEncryptionStatus (hwndDlg))
+ {
+ CloseSysEncMutex ();
+ return;
+ }
+ ManageStartupSeqWiz (TRUE, L"");
+ }
+ else
+ NormalCursor ();
+
CloseSysEncMutex ();
Info ("EFI_BOOT_LOADER_REPAIR_SUCCESS", hwndDlg);
}
diff --git a/src/Common/Dlgcode.c b/src/Common/Dlgcode.c
index 9349f470..33fedf60 100644
--- a/src/Common/Dlgcode.c
+++ b/src/Common/Dlgcode.c
@@ -269,11 +269,13 @@ HCURSOR hCursor = NULL;
ATOM hDlgClass, hSplashClass;
-/* This value may changed only by calling ChangeSystemEncryptionStatus(). Only the wizard can change it
-(others may still read it though). */
+/* This value may be changed only by calling ChangeSystemEncryptionStatus() or ClearSystemEncryptionStatus().
+Only the wizard normally changes it: the main application may clear it after EFI repair has completed
+post-decryption finalization. Others may still read it though. */
int SystemEncryptionStatus = SYSENC_STATUS_NONE;
-/* Only the wizard can change this value (others may only read it). */
+/* Only the wizard normally changes this value. ClearSystemEncryptionStatus() clears it together
+with SystemEncryptionStatus after EFI repair finalizes decryption. Others may only read it. */
WipeAlgorithmId nWipeMode = TC_WIPE_NONE;
BOOL bSysPartitionSelected = FALSE; /* TRUE if the user selected the system partition via the Select Device dialog */
@@ -3588,6 +3590,57 @@ BOOL LoadSysEncSettings ()
return status;
}
+static BOOL CALLBACK BroadcastSysEncCfgUpdateCommonCallb (HWND hwnd, LPARAM lParam)
+{
+ LONG_PTR userDataVal = GetWindowLongPtrW (hwnd, GWLP_USERDATA);
+ if ((userDataVal == (LONG_PTR) 'VERA') || (userDataVal == (LONG_PTR) 'TRUE')) // Prior to 1.0e, 'TRUE' was used for VeraCrypt dialogs
+ {
+ wchar_t name[1024] = { 0 };
+ GetWindowText (hwnd, name, ARRAYSIZE (name) - 1);
+ if (hwnd != MainDlg && wcsstr (name, L"VeraCrypt"))
+ {
+ PostMessage (hwnd, TC_APPMSG_SYSENC_CONFIG_UPDATE, 0, 0);
+ }
+ }
+ return TRUE;
+}
+
+static BOOL BroadcastSysEncCfgUpdateCommon (void)
+{
+ BOOL bSuccess = FALSE;
+ EnumWindows (BroadcastSysEncCfgUpdateCommonCallb, (LPARAM) &bSuccess);
+ return bSuccess;
+}
+
+BOOL ClearSystemEncryptionStatus (HWND hwndDlg)
+{
+ BOOL bMutexAlreadyHeld = InstanceHasSysEncMutex ();
+ wchar_t *sysEncCfgPath = GetConfigPath (TC_APPD_FILENAME_SYSTEM_ENCRYPTION);
+
+ if (!bMutexAlreadyHeld && !CreateSysEncMutex ())
+ {
+ Error ("SYSTEM_ENCRYPTION_IN_PROGRESS_ELSEWHERE", hwndDlg);
+ return FALSE;
+ }
+
+ if (FileExists (sysEncCfgPath) && _wremove (sysEncCfgPath) != 0)
+ {
+ Error ("CANNOT_SAVE_SYS_ENCRYPTION_SETTINGS", hwndDlg);
+ if (!bMutexAlreadyHeld)
+ CloseSysEncMutex ();
+ return FALSE;
+ }
+
+ SystemEncryptionStatus = SYSENC_STATUS_NONE;
+ nWipeMode = TC_WIPE_NONE;
+ BroadcastSysEncCfgUpdateCommon ();
+
+ if (!bMutexAlreadyHeld)
+ CloseSysEncMutex ();
+
+ return TRUE;
+}
+
// Returns the number of partitions where non-system in-place encryption is progress or had been in progress
// but was interrupted. In addition, via the passed pointer, returns the last selected wipe algorithm ID.